@@ -4,7 +4,7 @@ from six.moves.urllib import parse as urlparse
 import datetime
 from django.http import QueryDict
 from django.conf import settings
-from django.core.urlresolvers import reverse
+from django.urls import reverse
 from django.utils.html import escape
 from django.test import TestCase
 from django.contrib.auth.models import User
