@@ -2,7 +2,7 @@ import json
 from six.moves.urllib import parse as urlparse
 from django.http import HttpResponse
 from django.http import HttpResponseRedirect, QueryDict
-from django.utils.translation import ugettext as _
+from django.utils.translation import gettext as _
 from django.views.generic.base import TemplateView
 from django.core.exceptions import ObjectDoesNotExist
 from .oauth2.models import Client
